use std::{ops::Deref, sync::Arc};

#[derive(Clone)]
pub struct SharedApp(Arc<App>);

impl Deref for SharedApp {
    type Target = Arc<App>;

    fn deref(&self) -> &Self::Target {
        &self.0
    }
}

impl SharedApp {
    pub fn new(app: App) -> Self {
        Self(Arc::new(app))
    }
}

pub struct App {
    pub s3_client: aws_sdk_s3::Client,
}

impl App {
    pub async fn new() -> anyhow::Result<Self> {
        let shared_config = aws_config::load_from_env().await;
        let client = aws_sdk_s3::Client::new(&shared_config);

        Ok(Self { s3_client: client })
    }
}
